==> istio-model-v1beta1-5.11.2-sources.jar: io/fabric8/istio/api/networking/v1beta1/GatewayBuilder.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class GatewayBuilder extends io.fabric8.istio.api.networking.v1beta1.GatewayFluentImpl<io.fabric8.istio.api.networking.v1beta1.GatewayBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.istio.api.networking.v1beta1.Gateway,io.fabric8.istio.api.networking.v1beta1.GatewayBuilder>{
  public GatewayBuilder() {
    this(false);
  }
  public GatewayBuilder(java.lang.Boolean validationEnabled) {
    this(new Gateway(), validationEnabled);
  }
  public GatewayBuilder(io.fabric8.istio.api.networking.v1beta1.GatewayFluent<?> fluent) {
    this(fluent, false);
  }
  public GatewayBuilder(io.fabric8.istio.api.networking.v1beta1.GatewayFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Gateway(), validationEnabled);
  }
  public GatewayBuilder(io.fabric8.istio.api.networking.v1beta1.GatewayFluent<?> fluent,io.fabric8.istio.api.networking.v1beta1.Gateway instance) {
    this(fluent, instance, false);
  }
  public GatewayBuilder(io.fabric8.istio.api.networking.v1beta1.GatewayFluent<?> fluent,io.fabric8.istio.api.networking.v1beta1.Gateway instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  public GatewayBuilder(io.fabric8.istio.api.networking.v1beta1.Gateway instance) {
    this(instance,false);
  }
  public GatewayBuilder(io.fabric8.istio.api.networking.v1beta1.Gateway instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.istio.api.networking.v1beta1.GatewayFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.istio.api.networking.v1beta1.Gateway build() {
    Gateway buildable = new Gateway(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    GatewayBuilder that = (GatewayBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> istio-model-v1beta1-6.5.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/GatewayBuilder.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class GatewayBuilder extends GatewayFluentImpl<GatewayBuilder> implements VisitableBuilder<Gateway,GatewayBuilder>{
  public GatewayBuilder() {
    this(false);
  }
  public GatewayBuilder(Boolean validationEnabled) {
    this(new Gateway(), validationEnabled);
  }
  public GatewayBuilder(GatewayFluent<?> fluent) {
    this(fluent, false);
  }
  public GatewayBuilder(GatewayFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Gateway(), validationEnabled);
  }
  public GatewayBuilder(GatewayFluent<?> fluent,Gateway instance) {
    this(fluent, instance, false);
  }
  public GatewayBuilder(GatewayFluent<?> fluent,Gateway instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  public GatewayBuilder(Gateway instance) {
    this(instance,false);
  }
  public GatewayBuilder(Gateway instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  GatewayFluent<?> fluent;
  Boolean validationEnabled;
  public Gateway build() {
    Gateway buildable = new Gateway(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    return buildable;
  }
  
}
